==> flyyfluttersdk-1.0.0%2B1.tar.gz: lib/helpers/FlyyUtility.dart <==
import 'dart:convert';
import 'dart:io';

import 'package:advertising_id/advertising_id.dart';
import 'package:device_info/device_info.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:fluttertoast/fluttertoast.dart';
import 'package:flyyfluttersdk/Flyy.dart';
import 'package:flyyfluttersdk/helpers/EncryptedString.dart';
import 'package:flyyfluttersdk/model/FlyyAppInfo.dart';
import 'package:flyyfluttersdk/model/FlyyOfferMilestones.dart';
import 'package:flyyfluttersdk/model/FlyyOffers.dart';
import 'package:flyyfluttersdk/model/FlyyStepBean.dart';
import 'package:flyyfluttersdk/model/FlyyWalletCompleteData.dart';
import 'package:flyyfluttersdk/model/FlyyWalletModel.dart';
import 'package:html/parser.dart';
import 'package:http/http.dart' as http;
import 'package:intl/intl.dart';
import 'package:package_info/package_info.dart';
import 'package:shared_preferences/shared_preferences.dart';
import 'package:uuid_type/uuid_type.dart';

import 'APIClient.dart';
import 'SharedPrefTags.dart';

class FlyyUtility {
  static String checkInTitle = null;
  static List<FlyyStepBean> checkinBeanList;
  static List<FlyyWalletCompleteData> flyyWalletCompleteDataList = new List();

  static PackageInfo getPackageInfo() {
    PackageInfo.fromPlatform();
  }

  static Future<String> getPartnerToken() async {
    SharedPreferences sharedPreferences = await SharedPreferences.getInstance();
    return sharedPreferences.getString(SharedPrefTags.FLYY_PARTNER_KEY);
  }

  static Future<FlyyAppInfo> getFlyyAppInfoFromSp() async {
    SharedPreferences sharedPreferences = await SharedPreferences.getInstance();

    String response = sharedPreferences.getString(SharedPrefTags.FLYY_APP_INFO);
    final flyyAppInfo = FlyyAppInfo.fromJson(json.decode(response));

    return flyyAppInfo;
  }

  static Future<Map<String, String>> getHeadersMap(
      String key, String value) async {
    PackageInfo packageInfo = await PackageInfo.fromPlatform();

    var deviceInfoList = await getDeviceDetails();
    var gaid = await getGaid();
    var encryptedString = await EncryptedString.getEncryptedString(key, value);

    Map<String, String> headerMap = new Map();
    headerMap['X-Package-Name'] = packageInfo.packageName;
    headerMap['X-SDK-Version-Code'] = packageInfo.buildNumber;
    headerMap['X-SDK-Version-Name'] = packageInfo.version;
    headerMap['X-App-Version-Code'] = '0';
    headerMap['X-App-Version-Name'] = '';
    headerMap['X-Android-Id'] = deviceInfoList[2];
    headerMap['X-GAID'] = gaid;
    headerMap['X-App-Data'] = encryptedString;
    headerMap['X-User-Token'] = await getAuthToken();
    headerMap['X-Key'] = Flyy.PARTNER_TOKEN;

    return headerMap;
  }

  static Future<List<String>> getDeviceDetails() async {
    String model,
        deviceVersion,
        identifier,
        manufacturer,
        board,
        brand,
        device,
        display,
        host,
        id,
        product,
        tags,
        type;

    final DeviceInfoPlugin deviceInfoPlugin = new DeviceInfoPlugin();
    try {
      if (Platform.isAndroid) {
        var build = await deviceInfoPlugin.androidInfo;
        model = build.model;
        deviceVersion = build.version.toString();
        identifier = build.androidId; //UUID for Android
        manufacturer = build.manufacturer;
        board = build.board;
        brand = build.brand;
        device = build.device;
        display = build.display;
        host = build.host;
        id = build.id;
        product = build.product;
        tags = build.tags;
        type = build.type;
      } else if (Platform.isIOS) {
        var data = await deviceInfoPlugin.iosInfo;
        model = data.name;
        deviceVersion = data.systemVersion;
        identifier = data.identifierForVendor; //UUID for iOS
      }
    } on PlatformException {
      print('Failed to get platform version');
    }

//if (!mounted) return;
    return [
      model,
      deviceVersion,
      identifier,
      manufacturer,
      board,
      brand,
      device,
      display,
      host,
      id,
      product,
      tags,
      type,
    ];
  }

  static Future<String> getAuthToken() async {
    var deviceInfo = await getDeviceDetails();

    String m_szDevIDShort = "" +
        deviceInfo[4] +
        deviceInfo[5] +
        deviceInfo[6] +
        deviceInfo[7] +
        deviceInfo[8] +
        deviceInfo[9] +
        deviceInfo[3] +
        deviceInfo[0] +
        deviceInfo[10] +
        deviceInfo[11] +
        deviceInfo[12] +
        deviceInfo[2];

    List<int> bytes = utf8.encode(m_szDevIDShort);

    Uuid deviceUuid = Uuid.fromBytes(bytes);
    return deviceUuid.toString();
  }

  static getGaid() async {
    String advertisingId;
    // Platform messages may fail, so we use a try/catch PlatformException.
    try {
      advertisingId = await AdvertisingId.id;
    } on PlatformException {
      advertisingId = 'Failed to get platform version.';
    }
    return advertisingId;
  }

  static String cleanHtmlStrings(String textToClean) {
    return parse(textToClean).documentElement.text;
  }

  /*static String getFormattedDate(String dateTimeString) {
    DateTime formattedTime = DateTime.parse(dateTimeString);
    return DateFormat('dd-MM-yyyy').format(formattedTime);
  }*/

  static String getFormattedDateDDMMMYYY(String dateTimeString) {
    DateTime formattedTime = DateTime.parse(dateTimeString);
    return DateFormat('dd MMM yyy').format(formattedTime.toLocal());
  }

  static String setRewardText(int amount, String currency_label) {
    String strAmt = checkAmount(amount);
    if (currency_label != null) {
      if (equalsIgnoreCase(currency_label, 'cash')) {
        return "₹" + strAmt;
      } else {
        return strAmt + " " + currency_label;
      }
    } else
      return strAmt;
  }

  static String checkAmount(int amount) {
    String strAmt = amount.toString();
    if (amount != null && amount >= 10000) {
      double modifiedAmount = (amount / 1000);
      strAmt = (modifiedAmount).toString() + "k";
    }
    return strAmt;
  }

  static Color parseColor(String color) {
    if (color != null && color.isNotEmpty) {
      String hex = color.replaceAll("#", "");
      if (hex.isEmpty) hex = "ffffff";
      if (hex.length == 3) {
        hex =
            '${hex.substring(0, 1)}${hex.substring(0, 1)}${hex.substring(1, 2)}${hex.substring(1, 2)}${hex.substring(2, 3)}${hex.substring(2, 3)}';
      }
      Color col = Color(int.parse(hex, radix: 16)).withOpacity(1.0);
      return col;
    } else
      return Colors.black;
  }

  static bool equalsIgnoreCase(String a, String b) =>
      (a == null && b == null) ||
      (a != null && b != null && a.toLowerCase() == b.toLowerCase());

  static void showToast(
      BuildContext context, String message, ToastGravity gravity) {
    Fluttertoast.showToast(
        msg: message,
        toastLength: Toast.LENGTH_SHORT,
        gravity: gravity,
        backgroundColor: Flyy.TOOLBAR_COLOR,
        textColor: Colors.white,
        fontSize: 16.0);
  }

  static bool isValidEmail(String emailText) {
    return RegExp(
            r'^(([^<>()[\]\\.,;:\s@\"]+(\.[^<>()[\]\\.,;:\s@\"]+)*)|(\".+\"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$')
        .hasMatch(emailText);
  }

  static Future<String> getPublicIP() async {
    try {
      const url = 'https://api.ipify.org';
      var response = await http.get(url);
      if (response.statusCode == 200) {
        // The response body is the IP in plain text, so just
        // return it as-is.
        return response.body;
      } else {
        // The request failed with a non-200 code
        // The ipify.org API has a lot of guaranteed uptime
        // promises, so this shouldn't ever actually happen.
        print(response.statusCode);
        print(response.body);
        return null;
      }
    } catch (e) {
      // Request failed due to an error, most likely because
      // the phone isn't connected to the internet.
      print(e);
      return null;
    }
  }

  static String getNetworkConnectionType() {
    /* var connectivityResult = (Connectivity().checkConnectivity());
    // ignore: unrelated_type_equality_checks
    if (connectivityResult == ConnectivityResult.mobile) {
      return "mobile";
      // ignore: unrelated_type_equality_checks
    } else if (connectivityResult == ConnectivityResult.wifi) {
      return "wifi";
    }
    return "";*/
    return "mobile";
  }

  static Future<bool> checkIfInterentPresent() async {
    try {
      final result = await InternetAddress.lookup('google.com');
      if (result.isNotEmpty && result[0].rawAddress.isNotEmpty) {
        return true;
      }
    } on SocketException catch (_) {
      return false;
    }
  }

  static String getTimeFormat(String dateTimeString) {
    DateTime formattedTime = DateTime.parse(dateTimeString);
    return DateFormat("HH:mm").format(formattedTime.toLocal());
  }

  static String getDateFormat(String dateTimeString) {
    DateTime formattedTime = DateTime.parse(dateTimeString);
    return DateFormat("dd MMM").format(formattedTime.toLocal());
  }

  static Future<FlyyWalletModel> fetchWalletData() async {
    final response = await APIClient.getClient("web_wallet");
    if (response.statusCode == 200) {
      final responseJson = json.decode(response.body);
      FlyyWalletModel flyyWalletModel = FlyyWalletModel.fromJson(responseJson);

      if (flyyWalletModel != null) {
        flyyWalletCompleteDataList.clear();
        flyyWalletCompleteDataList.addAll(flyyWalletModel.flyyWalletData);
        saveWalletData(response.body, flyyWalletModel);
      }
      return flyyWalletModel;
    } else {
      throw Exception('Failed to load data ' + response.toString());
    }
  }

  static Future<void> saveWalletData(
      String response, FlyyWalletModel flyyWalletModel) async {
    SharedPreferences sharedPreferences = await SharedPreferences.getInstance();
    sharedPreferences = await SharedPreferences.getInstance();

    sharedPreferences.setString(SharedPrefTags.FLYY_WALLET_DATA, response);

    if (flyyWalletModel.activeCurrency != null) {
      sharedPreferences.setString(SharedPrefTags.SP_CURRENCY_LABEL,
          flyyWalletModel.activeCurrency.label);
      sharedPreferences.setString(SharedPrefTags.SP_CURRENCY_ICON_URL,
          flyyWalletModel.activeCurrency.icon);
    }
    if (flyyWalletModel.flyyWalletData != null) {
      for (FlyyWalletCompleteData data in flyyWalletModel.flyyWalletData) {
        if (data.rewardType == flyyWalletModel.activeCurrency.label) {
          sharedPreferences.setInt(
              SharedPrefTags.SP_CURRENCY_BALANCE, data.balance);
          break;
        }
      }
    }
  }

  static Future<String> getActiveCurrencyLabel() async {
    SharedPreferences sharedPreferences = await SharedPreferences.getInstance();
    if (sharedPreferences.getString(SharedPrefTags.SP_CURRENCY_LABEL) != null &&
        sharedPreferences
            .getString(SharedPrefTags.SP_CURRENCY_LABEL)
            .isNotEmpty) {
      return sharedPreferences.getString(SharedPrefTags.SP_CURRENCY_LABEL);
    } else
      return null;
  }

  static Future<String> getActiveCurrencyIconUrl() async {
    SharedPreferences sharedPreferences = await SharedPreferences.getInstance();
    if (sharedPreferences.getString(SharedPrefTags.SP_CURRENCY_ICON_URL) !=
            null &&
        sharedPreferences
            .getString(SharedPrefTags.SP_CURRENCY_ICON_URL)
            .isNotEmpty) {
      return sharedPreferences.getString(SharedPrefTags.SP_CURRENCY_ICON_URL);
    } else
      return null;
  }

  static Future<int> getActiveCurrencyBalance() async {
    SharedPreferences sharedPreferences = await SharedPreferences.getInstance();
    if (sharedPreferences.getInt(SharedPrefTags.SP_CURRENCY_BALANCE) != null) {
      return sharedPreferences.getInt(SharedPrefTags.SP_CURRENCY_BALANCE);
    } else
      return null;
  }

  static Future<FlyyWalletModel> getWalletData() async {
    SharedPreferences sharedPreferences = await SharedPreferences.getInstance();
    if (sharedPreferences.getString(SharedPrefTags.FLYY_WALLET_DATA) != null &&
        sharedPreferences
            .getString(SharedPrefTags.FLYY_WALLET_DATA)
            .isNotEmpty) {
      final responseJson = json
          .decode(sharedPreferences.getString(SharedPrefTags.FLYY_WALLET_DATA));
      FlyyWalletModel flyyWalletModel = FlyyWalletModel.fromJson(responseJson);
      return flyyWalletModel;
    } else
      return null;
  }

  static List<FlyyStepBean> getBeanList(FlyyOffers checkInData) {
    List<FlyyStepBean> stepsList = new List();
    List<FlyyOfferMilestones> mileStonesList = checkInData.flyyOfferMilestones;
    List<int> rewardValues = new List();
    String checkinDay = "";

    if (mileStonesList != null) {
      for (int i = 0; i < mileStonesList.length; i++) {
        rewardValues.add(int.parse(mileStonesList[i].value));
      }
      for (int j = 1; j <= checkInData.totalStreak; j++) {
        if (rewardValues.contains(j)) {
          if (j <= checkInData.streak) {
            stepsList.add(new FlyyStepBean(
                "WON",
                "https://ghc.theflyy.com/assets/fs_assets/ic_level.svg",
                FlyyStepBean.STEP_COMPLETED,
                FontWeight.bold));
          } else
            stepsList.add(new FlyyStepBean("Earn", checkInData.currencyIconUrl,
                FlyyStepBean.STEP_COMPLETED, FontWeight.normal));
        } else {
          if (j <= checkInData.streak) {
            if (checkInData.rewardOnEvery.toLowerCase() == "checkins")
              checkinDay = getSuffix(j);
            else
              checkinDay = "Day " + j.toString();

            stepsList.add(new FlyyStepBean(
                checkinDay,
                "https://ghc.theflyy.com/assets/fs_assets/ic_checkin_filled.png",
                FlyyStepBean.STEP_COMPLETED,
                FontWeight.bold));
          } else {
            if (checkInData.rewardOnEvery.toLowerCase() == "checkins")
              checkinDay = getSuffix(j);
            else
              checkinDay = "Day " + j.toString();
            stepsList.add(new FlyyStepBean(
                checkinDay,
                "https://ghc.theflyy.com/assets/fs_assets/ic_checkin_filler.png",
                FlyyStepBean.STEP_UNDO,
                FontWeight.normal));
          }
        }
      }
    }
    if (stepsList != null && stepsList.length > 0) {
//      checkinBeanList = new List();
      checkinBeanList = (stepsList);
    }
//    checkinBeanList = stepsList;
    return stepsList;
  }

  ///capitalize evey first letter of each word
  static String titleCase(String text) {
    if (text == null) throw ArgumentError("string: $text");

    if (text.isEmpty) return text;

    return text
        .split(' ')
        .map((word) => word[0].toUpperCase() + word.substring(1))
        .join(' ');
  }

  static String getSuffix(int j) {
    switch (j) {
      case 1:
        return "1st";
      case 2:
        return "2nd";
      case 3:
        return "3rd";
      default:
        return j.toString() + "th";
    }
  }
}

==> flyyfluttersdk-1.0.1%2B1.tar.gz: lib/helpers/FlyyUtility.dart <==
import 'dart:convert';
import 'dart:io';

import 'package:advertising_id/advertising_id.dart';
import 'package:device_info/device_info.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:fluttertoast/fluttertoast.dart';
import 'package:flyyfluttersdk/Flyy.dart';
import 'package:flyyfluttersdk/helpers/EncryptedString.dart';
import 'package:flyyfluttersdk/model/FlyyAppInfo.dart';
import 'package:flyyfluttersdk/model/FlyyOfferMilestones.dart';
import 'package:flyyfluttersdk/model/FlyyOffers.dart';
import 'package:flyyfluttersdk/model/FlyyStepBean.dart';
import 'package:flyyfluttersdk/model/FlyyWalletCompleteData.dart';
import 'package:flyyfluttersdk/model/FlyyWalletModel.dart';
import 'package:html/parser.dart';
import 'package:http/http.dart' as http;
import 'package:intl/intl.dart';
import 'package:package_info/package_info.dart';
import 'package:shared_preferences/shared_preferences.dart';
import 'package:uuid_type/uuid_type.dart';

import 'APIClient.dart';
import 'SharedPrefTags.dart';

class FlyyUtility {
  static String checkInTitle = null;
  static List<FlyyStepBean> checkinBeanList;
  static List<FlyyWalletCompleteData> flyyWalletCompleteDataList = new List();

  PackageInfo getPackageInfo() {
    PackageInfo.fromPlatform();
  }

  Future<String> getPartnerToken() async {
    SharedPreferences sharedPreferences = await SharedPreferences.getInstance();
    return sharedPreferences.getString(SharedPrefTags.FLYY_PARTNER_KEY);
  }

  Future<FlyyAppInfo> getFlyyAppInfoFromSp() async {
    SharedPreferences sharedPreferences = await SharedPreferences.getInstance();

    String response = sharedPreferences.getString(SharedPrefTags.FLYY_APP_INFO);
    final flyyAppInfo = FlyyAppInfo.fromJson(json.decode(response));

    return flyyAppInfo;
  }

  Future<Map<String, String>> getHeadersMap(
      String key, String value) async {
    PackageInfo packageInfo = await PackageInfo.fromPlatform();

    var deviceInfoList = await getDeviceDetails();
    var gaid = await getGaid();
    EncryptedString encryptedStringObj = new EncryptedString();
    var encryptedString = await encryptedStringObj.getEncryptedString(key, value);

    Map<String, String> headerMap = new Map();
    headerMap['X-Package-Name'] = packageInfo.packageName;
    headerMap['X-SDK-Version-Code'] = packageInfo.buildNumber;
    headerMap['X-SDK-Version-Name'] = packageInfo.version;
    headerMap['X-App-Version-Code'] = '0';
    headerMap['X-App-Version-Name'] = '';
    headerMap['X-Android-Id'] = deviceInfoList[2];
    headerMap['X-GAID'] = gaid;
    headerMap['X-App-Data'] = encryptedString;
    headerMap['X-User-Token'] = await getAuthToken();
    headerMap['X-Key'] = Flyy.PARTNER_TOKEN;

    return headerMap;
  }

   Future<List<String>> getDeviceDetails() async {
    String model,
        deviceVersion,
        identifier,
        manufacturer,
        board,
        brand,
        device,
        display,
        host,
        id,
        product,
        tags,
        type;

    final DeviceInfoPlugin deviceInfoPlugin = new DeviceInfoPlugin();
    try {
      if (Platform.isAndroid) {
        var build = await deviceInfoPlugin.androidInfo;
        model = build.model;
        deviceVersion = build.version.toString();
        identifier = build.androidId; //UUID for Android
        manufacturer = build.manufacturer;
        board = build.board;
        brand = build.brand;
        device = build.device;
        display = build.display;
        host = build.host;
        id = build.id;
        product = build.product;
        tags = build.tags;
        type = build.type;
      } else if (Platform.isIOS) {
        var data = await deviceInfoPlugin.iosInfo;
        model = data.name;
        deviceVersion = data.systemVersion;
        identifier = data.identifierForVendor; //UUID for iOS
      }
    } on PlatformException {
      print('Failed to get platform version');
    }

//if (!mounted) return;
    return [
      model,
      deviceVersion,
      identifier,
      manufacturer,
      board,
      brand,
      device,
      display,
      host,
      id,
      product,
      tags,
      type,
    ];
  }

   Future<String> getAuthToken() async {
    var deviceInfo = await getDeviceDetails();

    String m_szDevIDShort = "" +
        deviceInfo[4] +
        deviceInfo[5] +
        deviceInfo[6] +
        deviceInfo[7] +
        deviceInfo[8] +
        deviceInfo[9] +
        deviceInfo[3] +
        deviceInfo[0] +
        deviceInfo[10] +
        deviceInfo[11] +
        deviceInfo[12] +
        deviceInfo[2];

    List<int> bytes = utf8.encode(m_szDevIDShort);

    Uuid deviceUuid = Uuid.fromBytes(bytes);
    return deviceUuid.toString();
  }

  getGaid() async {
    String advertisingId;
    // Platform messages may fail, so we use a try/catch PlatformException.
    try {
      advertisingId = await AdvertisingId.id;
    } on PlatformException {
      advertisingId = 'Failed to get platform version.';
    }
    return advertisingId;
  }

  static String cleanHtmlStrings(String textToClean) {
    return parse(textToClean).documentElement.text;
  }

  /*static String getFormattedDate(String dateTimeString) {
    DateTime formattedTime = DateTime.parse(dateTimeString);
    return DateFormat('dd-MM-yyyy').format(formattedTime);
  }*/

  static String getFormattedDateDDMMMYYY(String dateTimeString) {
    DateTime formattedTime = DateTime.parse(dateTimeString);
    return DateFormat('dd MMM yyy').format(formattedTime.toLocal());
  }

  String setRewardText(int amount, String currency_label) {
    String strAmt = checkAmount(amount);
    if (currency_label != null) {
      if (equalsIgnoreCase(currency_label, 'cash')) {
        return "₹" + strAmt;
      } else {
        return strAmt + " " + currency_label;
      }
    } else
      return strAmt;
  }

  String checkAmount(int amount) {
    String strAmt = amount.toString();
    if (amount != null && amount >= 10000) {
      double modifiedAmount = (amount / 1000);
      strAmt = (modifiedAmount).toString() + "k";
    }
    return strAmt;
  }

  static Color parseColor(String color) {
    if (color != null && color.isNotEmpty) {
      String hex = color.replaceAll("#", "");
      if (hex.isEmpty) hex = "ffffff";
      if (hex.length == 3) {
        hex =
            '${hex.substring(0, 1)}${hex.substring(0, 1)}${hex.substring(1, 2)}${hex.substring(1, 2)}${hex.substring(2, 3)}${hex.substring(2, 3)}';
      }
      Color col = Color(int.parse(hex, radix: 16)).withOpacity(1.0);
      return col;
    } else
      return Colors.black;
  }

  static bool equalsIgnoreCase(String a, String b) =>
      (a == null && b == null) ||
      (a != null && b != null && a.toLowerCase() == b.toLowerCase());

  static void showToast(
      BuildContext context, String message, ToastGravity gravity) {
    Fluttertoast.showToast(
        msg: message,
        toastLength: Toast.LENGTH_SHORT,
        gravity: gravity,
        backgroundColor: Flyy.TOOLBAR_COLOR,
        textColor: Colors.white,
        fontSize: 16.0);
  }

  static bool isValidEmail(String emailText) {
    return RegExp(
            r'^(([^<>()[\]\\.,;:\s@\"]+(\.[^<>()[\]\\.,;:\s@\"]+)*)|(\".+\"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$')
        .hasMatch(emailText);
  }

  Future<String> getPublicIP() async {
    try {
      const url = 'https://api.ipify.org';
      var response = await http.get(url);
      if (response.statusCode == 200) {
        // The response body is the IP in plain text, so just
        // return it as-is.
        return response.body;
      } else {
        // The request failed with a non-200 code
        // The ipify.org API has a lot of guaranteed uptime
        // promises, so this shouldn't ever actually happen.
        print(response.statusCode);
        print(response.body);
        return null;
      }
    } catch (e) {
      // Request failed due to an error, most likely because
      // the phone isn't connected to the internet.
      print(e);
      return null;
    }
  }

  String getNetworkConnectionType() {
    /* var connectivityResult = (Connectivity().checkConnectivity());
    // ignore: unrelated_type_equality_checks
    if (connectivityResult == ConnectivityResult.mobile) {
      return "mobile";
      // ignore: unrelated_type_equality_checks
    } else if (connectivityResult == ConnectivityResult.wifi) {
      return "wifi";
    }
    return "";*/
    return "mobile";
  }

  static Future<bool> checkIfInterentPresent() async {
    try {
      final result = await InternetAddress.lookup('google.com');
      if (result.isNotEmpty && result[0].rawAddress.isNotEmpty) {
        return true;
      }
    } on SocketException catch (_) {
      return false;
    }
  }

  static String getTimeFormat(String dateTimeString) {
    DateTime formattedTime = DateTime.parse(dateTimeString);
    return DateFormat("HH:mm").format(formattedTime.toLocal());
  }

  static String getDateFormat(String dateTimeString) {
    DateTime formattedTime = DateTime.parse(dateTimeString);
    return DateFormat("dd MMM").format(formattedTime.toLocal());
  }

  Future<FlyyWalletModel> fetchWalletData() async {
    final response = await new APIClient().getClient("web_wallet");
    if (response.statusCode == 200) {
      final responseJson = json.decode(response.body);
      FlyyWalletModel flyyWalletModel = FlyyWalletModel.fromJson(responseJson);

      if (flyyWalletModel != null) {
        flyyWalletCompleteDataList.clear();
        flyyWalletCompleteDataList.addAll(flyyWalletModel.flyyWalletData);
        saveWalletData(response.body, flyyWalletModel);
      }
      return flyyWalletModel;
    } else {
      throw Exception('Failed to load data ' + response.toString());
    }
  }

  Future<void> saveWalletData(
      String response, FlyyWalletModel flyyWalletModel) async {
    SharedPreferences sharedPreferences = await SharedPreferences.getInstance();
    sharedPreferences = await SharedPreferences.getInstance();

    sharedPreferences.setString(SharedPrefTags.FLYY_WALLET_DATA, response);

    if (flyyWalletModel.activeCurrency != null) {
      sharedPreferences.setString(SharedPrefTags.SP_CURRENCY_LABEL,
          flyyWalletModel.activeCurrency.label);
      sharedPreferences.setString(SharedPrefTags.SP_CURRENCY_ICON_URL,
          flyyWalletModel.activeCurrency.icon);
    }
    if (flyyWalletModel.flyyWalletData != null) {
      for (FlyyWalletCompleteData data in flyyWalletModel.flyyWalletData) {
        if (data.rewardType == flyyWalletModel.activeCurrency.label) {
          sharedPreferences.setInt(
              SharedPrefTags.SP_CURRENCY_BALANCE, data.balance);
          break;
        }
      }
    }
  }

  Future<String> getActiveCurrencyLabel() async {
    SharedPreferences sharedPreferences = await SharedPreferences.getInstance();
    if (sharedPreferences.getString(SharedPrefTags.SP_CURRENCY_LABEL) != null &&
        sharedPreferences
            .getString(SharedPrefTags.SP_CURRENCY_LABEL)
            .isNotEmpty) {
      return sharedPreferences.getString(SharedPrefTags.SP_CURRENCY_LABEL);
    } else
      return null;
  }

  Future<String> getActiveCurrencyIconUrl() async {
    SharedPreferences sharedPreferences = await SharedPreferences.getInstance();
    if (sharedPreferences.getString(SharedPrefTags.SP_CURRENCY_ICON_URL) !=
            null &&
        sharedPreferences
            .getString(SharedPrefTags.SP_CURRENCY_ICON_URL)
            .isNotEmpty) {
      return sharedPreferences.getString(SharedPrefTags.SP_CURRENCY_ICON_URL);
    } else
      return null;
  }

  Future<int> getActiveCurrencyBalance() async {
    SharedPreferences sharedPreferences = await SharedPreferences.getInstance();
    if (sharedPreferences.getInt(SharedPrefTags.SP_CURRENCY_BALANCE) != null) {
      return sharedPreferences.getInt(SharedPrefTags.SP_CURRENCY_BALANCE);
    } else
      return null;
  }

  Future<FlyyWalletModel> getWalletData() async {
    SharedPreferences sharedPreferences = await SharedPreferences.getInstance();
    if (sharedPreferences.getString(SharedPrefTags.FLYY_WALLET_DATA) != null &&
        sharedPreferences
            .getString(SharedPrefTags.FLYY_WALLET_DATA)
            .isNotEmpty) {
      final responseJson = json
          .decode(sharedPreferences.getString(SharedPrefTags.FLYY_WALLET_DATA));
      FlyyWalletModel flyyWalletModel = FlyyWalletModel.fromJson(responseJson);
      return flyyWalletModel;
    } else
      return null;
  }

  List<FlyyStepBean> getBeanList(FlyyOffers checkInData) {
    List<FlyyStepBean> stepsList = new List();
    List<FlyyOfferMilestones> mileStonesList = checkInData.flyyOfferMilestones;
    List<int> rewardValues = new List();
    String checkinDay = "";

    if (mileStonesList != null) {
      for (int i = 0; i < mileStonesList.length; i++) {
        rewardValues.add(int.parse(mileStonesList[i].value));
      }
      for (int j = 1; j <= checkInData.totalStreak; j++) {
        if (rewardValues.contains(j)) {
          if (j <= checkInData.streak) {
            stepsList.add(new FlyyStepBean(
                "WON",
                "https://ghc.theflyy.com/assets/fs_assets/ic_level.svg",
                FlyyStepBean.STEP_COMPLETED,
                FontWeight.bold));
          } else
            stepsList.add(new FlyyStepBean("Earn", checkInData.currencyIconUrl,
                FlyyStepBean.STEP_COMPLETED, FontWeight.normal));
        } else {
          if (j <= checkInData.streak) {
            if (checkInData.rewardOnEvery.toLowerCase() == "checkins")
              checkinDay = getSuffix(j);
            else
              checkinDay = "Day " + j.toString();

            stepsList.add(new FlyyStepBean(
                checkinDay,
                "https://ghc.theflyy.com/assets/fs_assets/ic_checkin_filled.png",
                FlyyStepBean.STEP_COMPLETED,
                FontWeight.bold));
          } else {
            if (checkInData.rewardOnEvery.toLowerCase() == "checkins")
              checkinDay = getSuffix(j);
            else
              checkinDay = "Day " + j.toString();
            stepsList.add(new FlyyStepBean(
                checkinDay,
                "https://ghc.theflyy.com/assets/fs_assets/ic_checkin_filler.png",
                FlyyStepBean.STEP_UNDO,
                FontWeight.normal));
          }
        }
      }
    }
    if (stepsList != null && stepsList.length > 0) {
//      checkinBeanList = new List();
      checkinBeanList = (stepsList);
    }
//    checkinBeanList = stepsList;
    return stepsList;
  }

  ///capitalize evey first letter of each word
  static String titleCase(String text) {
    if (text == null) throw ArgumentError("string: $text");

    if (text.isEmpty) return text;

    return text
        .split(' ')
        .map((word) => word[0].toUpperCase() + word.substring(1))
        .join(' ');
  }

  static String getSuffix(int j) {
    switch (j) {
      case 1:
        return "1st";
      case 2:
        return "2nd";
      case 3:
        return "3rd";
      default:
        return j.toString() + "th";
    }
  }
}
